@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -21,14 +21,14 @@ class Blob : public Bitmap
   std::vector< Bitmap * > holepv;		// vector of holes
 
 public:
-  Blob( const int l, const int t, const int r, const int b ) throw()
+  Blob( const int l, const int t, const int r, const int b )
     : Bitmap( l, t, r, b ) {}
 
-  Blob( const Bitmap & source, const Rectangle & re ) throw()
+  Blob( const Bitmap & source, const Rectangle & re )
     : Bitmap( source, re ) {}
 
-  Blob( const Blob & b ) throw();
-  Blob & operator=( const Blob & b ) throw();
+  Blob( const Blob & b );
+  Blob & operator=( const Blob & b );
 
   ~Blob() throw();
 
@@ -38,12 +38,12 @@ public:
   using Bitmap::bottom;
   using Bitmap::height;
   using Bitmap::width;
-  void left  ( const int l ) throw();
-  void top   ( const int t ) throw();
-  void right ( const int r ) throw();
-  void bottom( const int b ) throw();
-  void height( const int h ) throw() { bottom( top() + h - 1 ); }
-  void width ( const int w ) throw() { right( left() + w - 1 ); }
+  void left  ( const int l );
+  void top   ( const int t );
+  void right ( const int r );
+  void bottom( const int b );
+  void height( const int h ) { bottom( top() + h - 1 ); }
+  void width ( const int w ) { right( left() + w - 1 ); }
 
   const Bitmap & hole( const int i ) const throw();
   int holes() const throw() { return holepv.size(); }
@@ -52,6 +52,6 @@ public:
 
   void print( FILE * const outfile ) const throw();
 
-  void fill_hole( const int i ) throw();
-  void find_holes() throw();
+  void fill_hole( const int i );
+  void find_holes();
   };
