@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -32,7 +32,7 @@
 
 // First attempt at recognition without relying on context.
 //
-void Character::recognize1( const Charset & charset, const Rectangle & charbox ) throw()
+void Character::recognize1( const Charset & charset, const Rectangle & charbox )
   {
   if( blobs() == 1 ) recognize11( charset, charbox );
   else if( blobs() == 2 ) recognize12( charset, charbox );
@@ -44,7 +44,7 @@ void Character::recognize1( const Charset & charset, const Rectangle & charbox )
 // 0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghklmnopqrstuvwxyz
 // #$&'()*+,-./<>@[\]^_`{|}~
 //
-void Character::recognize11( const Charset & charset, const Rectangle & charbox ) throw()
+void Character::recognize11( const Charset & charset, const Rectangle & charbox )
   {
   const Blob & b = blob( 0 );
   if( b.holes() == 0 ) recognize110( charset, charbox );
@@ -57,7 +57,7 @@ void Character::recognize11( const Charset & charset, const Rectangle & charbox
 // 12357CEFGHIJKLMNSTUVWXYZcfhklmnrstuvwxyz
 // '()*+,-./<>@[\]^_`{|}~
 //
-void Character::recognize110( const Charset & charset, const Rectangle & charbox ) throw()
+void Character::recognize110( const Charset & charset, const Rectangle & charbox )
   {
   const Blob & b = blob( 0 );
   Features f( b );
@@ -88,22 +88,16 @@ void Character::recognize110( const Charset & charset, const Rectangle & charbox
       while( --col > b.hpos( 40 ) &&
              ( b.seek_top( b.vcenter(), col ) > b.top() ||
                f.hp[col-b.left()] > b.height() / 10 ) ) ;
-      if( col > b.hpos( 40 ) && col < b.right() )
-        {
-        only_guess( 0, b.left() ); add_guess( 't', col );
-        add_guess( 'r', b.right() ); return;
-        }
+      if( col > b.hpos( 40 ) && col < b.right() &&
+          set_merged_guess( 't', col, 'r', 0 ) ) return;
       }
     }
   if( code == 'N' && b.width() > b.height() && b.top() >= charbox.top() &&
       4 * f.tp[f.tp.pos(50)] < b.height() )
     {					// Looks for merged 'rv'
     const int col = f.hp.iminimum();
-    if( col >= f.hp.pos( 40 ) && col < f.hp.pos( 50 ) )
-      {
-      only_guess( 0, b.left() ); add_guess ( 'r', b.left() + col );
-      add_guess( 'v', b.right() ); return;
-      }
+    if( col >= f.hp.pos( 40 ) && col < f.hp.pos( 50 ) &&
+        set_merged_guess( 'r', b.left() + col, 'v', 0 ) ) return;
     }
   if( code ) { add_guess( code, 0 ); return; }
   const int noise = ( std::min( b.height(), b.width() ) / 30 ) + 1;
@@ -121,24 +115,18 @@ void Character::recognize110( const Charset & charset, const Rectangle & charbox
         const int rgap = f.rp[f.rp.pos(50)];
         if( 10 * rgap > b.width() && !b.escape_top( b.vcenter(), b.right() ) )
           {
-          only_guess( 0, b.left() );
           const int lgap = f.lp[f.lp.pos(50)];
           if( 10 * lgap > b.width() && !b.escape_top( b.vcenter(), b.left() ) &&
               Ocrad::similar( lgap, rgap, 10 ) && b.top() < charbox.top() )
-            { add_guess( 'T', b.hcenter() ); add_guess( 'T', b.right() ); }
-          else { add_guess( 'r', b.hcenter() ); add_guess( 'r', b.right() ); }
-          return;
+            { if( set_merged_guess( 'T', b.hcenter(), 'T', 0 ) ) return; }
+          else if( set_merged_guess( 'r', b.hcenter(), 'r', 0 ) ) return;
           }
         }
       if( 2 * f.lp[f.lp.pos(10)] > b.width() && !f.rp.increasing( f.rp.pos( 75 ) ) )
         {
         const int col = b.seek_left( b.vcenter(), b.right() );
-        if( col <= b.hpos( 95 ) && !b.escape_top( b.vcenter(), col ) )
-          {
-          only_guess( 0, b.left() );
-          add_guess( 'r', b.hcenter() ); add_guess( 't', b.right() );
-          return;
-          }
+        if( col <= b.hpos( 95 ) && !b.escape_top( b.vcenter(), col ) &&
+            set_merged_guess( 'r', b.hcenter(), 't', 0 ) ) return;
         }
       if( f.rp.minima() == 1 && !f.rp.increasing( f.rp.pos( 75 ) ) )
         {
@@ -153,12 +141,8 @@ void Character::recognize110( const Charset & charset, const Rectangle & charbox
             int col, limit = b.seek_right( b.vcenter(), b.hcenter() );
             for( col = b.hcenter(); col <= limit; ++col )
               if( b.seek_bottom( b.vcenter(), col ) < b.bottom() ) break;
-            if( col > b.left() && col < b.right() )
-              {
-              only_guess( 0, b.left() );
-              add_guess( 'f', col - 1 ); add_guess( 'l', b.right() );
-              return;
-              }
+            if( col > b.left() && col < b.right() &&
+                set_merged_guess( 'f', col - 1, 'l', 0 ) ) return;
             }
           }
         }
@@ -175,24 +159,18 @@ void Character::recognize110( const Charset & charset, const Rectangle & charbox
             if( f.hp[i-b.left()] < hmin )
               { hmin = f.hp[i-b.left()]; col = i; }
           if( col > b.left() && col < b.right() )
-            { only_guess( 0, b.left() ); add_guess( 'r', col - 1 );
-            add_guess( 'f', b.right() ); }
+            set_merged_guess( 'r', col - 1, 'f', 0 );
           }
         return;
         }
       if( f.rp.isctip( 30 ) )
-        {
-        only_guess( 0, b.left() ); add_guess( 'f', b.hcenter() );
-        add_guess( 'i', b.right() ); return;
-        }
+        { set_merged_guess( 'f', b.hcenter(), 'i', 0 ); return; }
       }
     else if( code == 'k' )	// Looks for merged 'rt'
       {
-      if( 2 * f.lp[f.lp.pos(10)] > b.width() && !f.rp.increasing( f.rp.pos( 75 ) ) )
-        {
-        only_guess( 0, b.left() ); add_guess( 'r', b.hcenter() );
-        add_guess( 't', b.right() ); return;
-        }
+      if( 2 * f.lp[f.lp.pos(10)] > b.width() &&
+          !f.rp.increasing( f.rp.pos( 75 ) ) &&
+          set_merged_guess( 'r', b.hcenter(), 't', 0 ) ) return;
       }
     if( code ) { add_guess( code, 0 ); return; }
     }
@@ -210,9 +188,8 @@ void Character::recognize110( const Charset & charset, const Rectangle & charbox
       int col = b.seek_right( row, b.left() );
       col = b.seek_right( row, col + 1, false );
       col = b.seek_right( row, col + 1 );
-      if( col > b.left() && col < b.right() )
-        { only_guess( 0, b.left() ); add_guess( 'r', col );
-        add_guess( 'n', b.right() ); return; }
+      if( col > b.left() && col < b.right() &&
+          set_merged_guess( 'r', col, 'n', 0 ) ) return;
       }
     if( f.tp.minima( b.height() / 3 ) == 1 ) add_guess( 'm', 0 );
     return;
@@ -223,9 +200,8 @@ void Character::recognize110( const Charset & charset, const Rectangle & charbox
     int col = b.seek_right( row, b.left() );
     col = b.seek_right( row, col + 1, false );
     col = b.seek_right( row, col + 1 );
-    if( col > b.left() && col < b.right() )
-      { only_guess( 0, b.left() ); add_guess( 'r', col );
-      add_guess( 'm', b.right() ); return; }
+    if( col > b.left() && col < b.right() &&
+        set_merged_guess( 'r', col, 'm', 0 ) ) return;
     }
 
   if( f.tp.minima( b.height() / 4 ) == 3 )
@@ -248,7 +224,7 @@ void Character::recognize110( const Charset & charset, const Rectangle & charbox
 // Recognizes 1 blob characters with 1 hole.
 // 0469ADOPQRabdegopq#
 //
-void Character::recognize111( const Charset & charset, const Rectangle & charbox ) throw()
+void Character::recognize111( const Charset & charset, const Rectangle & charbox )
   {
   const Blob & b = blob( 0 );
   const Bitmap & h = b.hole( 0 );
@@ -299,7 +275,7 @@ void Character::recognize111( const Charset & charset, const Rectangle & charbox
 // Recognizes 1 blob characters with 2 holes.
 // 8BQg$&
 //
-void Character::recognize112( const Rectangle & charbox ) throw()
+void Character::recognize112( const Rectangle & charbox )
   {
   const Blob & b = blob( 0 );
   const Bitmap & h1 = b.hole( 0 );		// upper hole
