@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -36,7 +36,7 @@ const char * const charset_name[charsets] =
 
 struct F_entry
   {
-  const char * name;
+  const char * const name;
   Filter::Type type;
   };
 
@@ -52,7 +52,7 @@ const F_entry F_table[] =
 
 struct T_entry
   {
-  const char * name;
+  const char * const name;
   Transformation::Type type;
   };
 
@@ -74,14 +74,15 @@ const T_entry T_table[] =
 
 int verbosity = 0;
 
-void Ocrad::internal_error( const char * msg ) throw()
+void Ocrad::internal_error( const char * const msg ) throw()
   {
-  std::fprintf( stderr, "ocrad: internal error: %s\n", msg );
+  std::fprintf( stderr, "ocrad: internal error: %s.\n", msg );
   std::exit( 3 );
   }
 
 
-bool Ocrad::similar( int a, int b, int percent_dif, int abs_dif ) throw()
+bool Ocrad::similar( const int a, const int b,
+                     const int percent_dif, const int abs_dif ) throw()
   {
   int difference = std::abs( a - b );
   if( percent_dif > 0 && difference <= abs_dif ) return true;
@@ -90,7 +91,7 @@ bool Ocrad::similar( int a, int b, int percent_dif, int abs_dif ) throw()
   }
 
 
-bool Charset::enable( const char * name ) throw()
+bool Charset::enable( const char * const name ) throw()
   {
   for( int i = 0; i < charsets; ++i )
     if( std::strcmp( name, charset_name[i] ) == 0 )
@@ -99,21 +100,22 @@ bool Charset::enable( const char * name ) throw()
   }
 
 
-bool Charset::enabled( Value cset ) const throw()
+bool Charset::enabled( const Value cset ) const throw()
   {
   if( !charset_ ) return cset == iso_8859_15;		// default charset
   return charset_ & cset;
   }
 
 
-bool Charset::only( Value cset ) const throw()
+bool Charset::only( const Value cset ) const throw()
   {
   if( !charset_ ) return cset == iso_8859_15;		// default charset
   return charset_ == cset;
   }
 
 
-void Charset::show_error( const char * program_name, const char * arg ) const throw()
+void Charset::show_error( const char * const program_name,
+                          const char * const arg ) const throw()
   {
   if( verbosity >= 0 )
     {
@@ -127,7 +129,7 @@ void Charset::show_error( const char * program_name, const char * arg ) const th
   }
 
 
-bool Filter::set( const char * name ) throw()
+bool Filter::set( const char * const name ) throw()
   {
   for( int i = 0; F_table[i].name != 0; ++i )
     if( std::strcmp( name, F_table[i].name ) == 0 )
@@ -136,7 +138,8 @@ bool Filter::set( const char * name ) throw()
   }
 
 
-void Filter::show_error( const char * program_name, const char * arg ) const throw()
+void Filter::show_error( const char * const program_name,
+                         const char * const arg ) const throw()
   {
   if( verbosity >= 0 )
     {
@@ -150,7 +153,7 @@ void Filter::show_error( const char * program_name, const char * arg ) const thr
   }
 
 
-bool Transformation::set( const char * name ) throw()
+bool Transformation::set( const char * const name ) throw()
   {
   for( int i = 0; T_table[i].name != 0; ++i )
     if( std::strcmp( name, T_table[i].name ) == 0 )
@@ -159,7 +162,8 @@ bool Transformation::set( const char * name ) throw()
   }
 
 
-void Transformation::show_error( const char * program_name, const char * arg ) const throw()
+void Transformation::show_error( const char * const program_name,
+                                 const char * const arg ) const throw()
   {
   if( verbosity >= 0 )
     {
@@ -173,7 +177,7 @@ void Transformation::show_error( const char * program_name, const char * arg ) c
   }
 
 
-bool Control::set_format( const char * name ) throw()
+bool Control::set_format( const char * const name ) throw()
   {
   if( std::strcmp( name, "byte" ) == 0 ) { format = byte; return true; }
   if( std::strcmp( name, "utf8" ) == 0 ) { format = utf8; return true; }
