@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -29,19 +29,18 @@
 #include "feats.h"
 
 
-Features::Features( const Blob & b ) throw()
-  : blob_( &b ), hbars_( -1 ), vbars_( -1 ),
+Features::Features( const Blob & b_ )
+  : b( b_ ), hbars_( -1 ), vbars_( -1 ),
     hscan_valid( false ), vscan_valid( false ), lp( b, Profile::left ),
     tp( b, Profile::top ), rp( b, Profile::right ), bp( b, Profile::bottom ),
     hp( b, Profile::height ), wp( b, Profile::width )
   {}
 
 
-int Features::hbars() const throw()
+int Features::hbars() const
   {
   if( hbars_ < 0 )
     {
-    const Blob & b = *blob_;
     const int limit = wp.max() / 2;
     int state = 0, begin = 0, l = 0, r = 0;
     std::vector< int > count( b.height(), 0 );
@@ -87,11 +86,10 @@ int Features::hbars() const throw()
   }
 
 
-int Features::vbars() const throw()	// FIXME small gaps not detected
+int Features::vbars() const		// FIXME small gaps not detected
   {
   if( vbars_ < 0 )
     {
-    const Blob & b = *blob_;
     int state = 0, begin = 0, limit = b.height();
     limit -= ( b.height() < 40 ) ? 3 : b.height() / 10;
     vbars_ = 0;
@@ -139,11 +137,10 @@ int Features::vbars() const throw()	// FIXME small gaps not detected
 
 // return the number of horizontal traces crossing every column
 //
-const std::vector< int > & Features::hscan() const throw()
+const std::vector< int > & Features::hscan() const
   {
   if( !hscan_valid )
     {
-    const Blob & b = *blob_;
     int state = 0;
     hscan_valid = true; hscan_.resize( b.width() );
 
@@ -168,11 +165,10 @@ const std::vector< int > & Features::hscan() const throw()
 
 // return the number of vertical traces crossing every row
 //
-const std::vector< int > & Features::vscan() const throw()
+const std::vector< int > & Features::vscan() const
   {
   if( !vscan_valid )
     {
-    const Blob & b = *blob_;
     int state = 0;
     vscan_valid = true; vscan_.resize( b.height() );
 
@@ -195,10 +191,8 @@ const std::vector< int > & Features::vscan() const throw()
   }
 
 
-int Features::test_misc( const Rectangle & charbox ) const throw()
+int Features::test_misc( const Rectangle & charbox ) const
   {
-  const Blob & b = *blob_;
-
   if( hbars() == 1 && hbar(0).top() <= b.top() + ( b.height() / 10 ) &&
       4 * hbar(0).height() <= b.height() &&
       5 * hbar(0).width() >= 4 * b.width() &&
