@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -20,7 +20,8 @@ struct Segment
   {
   int left, right;				// l > r means no segment
 
-  Segment( int l = 1, int r = 0 ) : left( l ), right( r ) {}
+  Segment( const int l = 1, const int r = 0 ) throw()
+    : left( l ), right( r ) {}
 
   void add_point( const int col ) throw();
   void add_segment( const Segment & seg ) throw();
@@ -42,9 +43,9 @@ class Mask : public Rectangle
 
 public:
       // Creates a rectangular Mask
-  Mask( const Rectangle & re ) throw()
+  Mask( const Rectangle & re )
     : Rectangle( re ), data( height(), Segment( re.left(), re.right() ) ) {}
-  Mask( const int l, const int t, const int r, const int b ) throw()
+  Mask( const int l, const int t, const int r, const int b )
     : Rectangle( l, t, r, b ), data( height(), Segment( l, r ) ) {}
 
   using Rectangle::left;
@@ -53,16 +54,16 @@ public:
   using Rectangle::bottom;
   using Rectangle::height;
 
-  int left  ( const int row ) const throw();
-  int right ( const int row ) const throw();
+  int left ( const int row ) const throw();
+  int right( const int row ) const throw();
 
-  void top   ( const int t ) throw();
-  void bottom( const int b ) throw();
-  void height( const int h ) throw() { bottom( top() + h - 1 ); }
+  void top   ( const int t );
+  void bottom( const int b );
+  void height( const int h ) { bottom( top() + h - 1 ); }
 
-  void add_mask( const Mask & m ) throw();
-  void add_point( const int row, const int col ) throw();
-  void add_rectangle( const Rectangle & re ) throw();
+  void add_mask( const Mask & m );
+  void add_point( const int row, const int col );
+  void add_rectangle( const Rectangle & re );
 
   bool includes( const Rectangle & re ) const throw();
   bool includes( const int row, const int col ) const throw();
