@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -97,7 +97,7 @@ int absolute_pos( Rational pos, const int left, const int right ) throw()
   }
 
 
-void enlarge_2( std::vector< std::vector< unsigned char > > & data ) throw()
+void enlarge_2( std::vector< std::vector< unsigned char > > & data )
   {
   const int height = data.size(), width = data[0].size();
   std::vector< std::vector< unsigned char > > new_data( 2 * height );
@@ -134,7 +134,7 @@ void enlarge_2( std::vector< std::vector< unsigned char > > & data ) throw()
   }
 
 
-void enlarge_3( std::vector< std::vector< unsigned char > > & data ) throw()
+void enlarge_3( std::vector< std::vector< unsigned char > > & data )
   {
   const int height = data.size(), width = data[0].size();
   std::vector< std::vector< unsigned char > > new_data( 3 * height );
@@ -183,7 +183,7 @@ void enlarge_3( std::vector< std::vector< unsigned char > > & data ) throw()
   }
 
 
-void enlarge_n( std::vector< std::vector< unsigned char > > & data, const int n ) throw()
+void enlarge_n( std::vector< std::vector< unsigned char > > & data, const int n )
   {
   if( n < 2 ) return;
   const int height = data.size(), width = data[0].size();
@@ -221,7 +221,7 @@ void mirror_top_bottom( std::vector< std::vector< unsigned char > > & data ) thr
 
 
 void mirror_diagonal( std::vector< std::vector< unsigned char > > & data,
-                      Rectangle & re ) throw()
+                      Rectangle & re )
   {
   const int size = std::max( re.height(), re.width() );
 
@@ -362,7 +362,7 @@ void Page_image::threshold( const int th )
   }
 
 
-bool Page_image::cut( const Rational ltwh[4] ) throw()
+bool Page_image::cut( const Rational ltwh[4] )
   {
   Rectangle re = *this;
 
@@ -388,7 +388,7 @@ bool Page_image::cut( const Rational ltwh[4] ) throw()
     for( int row = data.size() - 1; row >= 0 ; --row ) data[row].resize( w );
     }
   if( re.top() > top() )
-    data.erase( data.begin(), data.begin() + re.top() - top() );
+    data.erase( data.begin(), data.begin() + ( re.top() - top() ) );
   if( re.left() > left() )
     {
     const int d = re.left() - left();
@@ -502,7 +502,7 @@ bool Page_image::scale( int n )
   }
 
 
-void Page_image::transform( const Transformation & t ) throw()
+void Page_image::transform( const Transformation & t )
   {
   switch( t.type() )
     {
