@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -142,44 +142,44 @@ int Rational::round() const throw()
 // Values may be preceded by an optional '+' or '-' sign.
 // Returns the number of chars read, or 0 if error.
 //
-int Rational::parse( const char * ptr ) throw()
+int Rational::parse( const char * const s ) throw()
   {
-  if( !ptr || !*ptr ) return 0;
+  if( !s || !s[0] ) return 0;
   int n = 0, d = 1, c = 0;
   bool minus = false;
 
-  while( std::isspace( ptr[c] ) ) ++c;
-  if( ptr[c] == '+' ) ++c;
-  else if( ptr[c] == '-' ) { ++c; minus = true; }
-  if( !std::isdigit( ptr[c] ) && ptr[c] != '.' ) return 0;
+  while( std::isspace( s[c] ) ) ++c;
+  if( s[c] == '+' ) ++c;
+  else if( s[c] == '-' ) { ++c; minus = true; }
+  if( !std::isdigit( s[c] ) && s[c] != '.' ) return 0;
 
-  while( std::isdigit( ptr[c] ) )
+  while( std::isdigit( s[c] ) )
     {
-    if( ( INT_MAX - (ptr[c] - '0') ) / 10 < n ) return 0;
-    n = (n * 10) + (ptr[c] - '0'); ++c;
+    if( ( INT_MAX - (s[c] - '0') ) / 10 < n ) return 0;
+    n = (n * 10) + (s[c] - '0'); ++c;
     }
 
-  if( ptr[c] == '.' )
+  if( s[c] == '.' )
     {
-    ++c; if( !std::isdigit( ptr[c] ) ) return 0;
-    while( std::isdigit( ptr[c] ) )
+    ++c; if( !std::isdigit( s[c] ) ) return 0;
+    while( std::isdigit( s[c] ) )
       {
-      if( ( INT_MAX - (ptr[c] - '0') ) / 10 < n || INT_MAX / 10 < d ) return 0;
-      n = (n * 10) + (ptr[c] - '0'); d *= 10; ++c;
+      if( ( INT_MAX - (s[c] - '0') ) / 10 < n || INT_MAX / 10 < d ) return 0;
+      n = (n * 10) + (s[c] - '0'); d *= 10; ++c;
       }
     }
-  else if( ptr[c] == '/' )
+  else if( s[c] == '/' )
     {
     ++c; d = 0;
-    while( std::isdigit( ptr[c] ) )
+    while( std::isdigit( s[c] ) )
       {
-      if( ( INT_MAX - (ptr[c] - '0') ) / 10 < d ) return 0;
-      d = (d * 10) + (ptr[c] - '0'); ++c;
+      if( ( INT_MAX - (s[c] - '0') ) / 10 < d ) return 0;
+      d = (d * 10) + (s[c] - '0'); ++c;
       }
     if( d == 0 ) return 0;
     }
 
-  if( ptr[c] == '%' )
+  if( s[c] == '%' )
     {
     ++c;
     if( n % 100 == 0 ) n /= 100;
@@ -197,7 +197,7 @@ int Rational::parse( const char * ptr ) throw()
 // Returns the fraction "num/den" as a floating point with "prec" decimals.
 // If 'prec' is negative, only the needed decimals are shown.
 //
-const std::string Rational::to_decimal( const unsigned int iwidth, int prec ) const throw()
+const std::string Rational::to_decimal( const unsigned int iwidth, int prec ) const
   {
   std::string s;
 
