@@ -1,9 +1,10 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005 Antonio Diaz Diaz.
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
+    Antonio Diaz Diaz.
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,25 +13,26 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 class Textblock : public Rectangle
   {
-  mutable std::vector< Textline > data;
+  mutable std::vector< Textline * > tlpv;
 
 public:
-  Textblock( const Rectangle & r, const Charset & charset,
-             const std::vector< std::vector< Block > > & block_matrix ) throw();
+  Textblock( const Rectangle & page, const Rectangle & block,
+             std::vector< Blob * > & blobp_vector );
+  ~Textblock() throw();
+  void recognize( const Charset & charset, const Filter & filter );
 
-  Textline & line( int i ) const throw();
-  int lines() const throw() { return data.size(); }
+  const Textline & textline( const int i ) const throw();
+  int textlines() const throw() { return tlpv.size(); }
   int characters() const throw();
 
   void print( const Control & control ) const throw();
   void dprint( const Control & control, bool graph, bool recursive ) const throw();
   void xprint( const Control & control ) const throw();
-  void cmark( Bitmap & bitmap ) const throw();
-  void lmark( Bitmap & bitmap ) const throw();
+  void cmark( Page_image & page_image ) const throw();
+  void lmark( Page_image & page_image ) const throw();
   };
