@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -16,8 +16,8 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <cstdio>
 #include <algorithm>
+#include <cstdio>
 #include <string>
 #include <vector>
 
@@ -39,14 +39,13 @@ namespace {
 struct Zone
   {
   Mask mask;
-//  std::vector< std::vector< Blob * > > blobp_matrix;
   std::vector< Blob * > blobp_vector;
   Zone( const Rectangle & re ) : mask( re ) {}
-  void join( Zone & z ) throw();
+  void join( Zone & z );
   };
 
 
-void Zone::join( Zone & z ) throw()
+void Zone::join( Zone & z )
   {
   mask.add_mask( z.mask );
   blobp_vector.insert( blobp_vector.end(),
@@ -64,7 +63,7 @@ int blobs_in_page( const std::vector< Zone > & zone_vector ) throw()
   }
 
 
-void bprint( const std::vector< Zone > & zone_vector, FILE * outfile ) throw()
+void bprint( const std::vector< Zone > & zone_vector, FILE * const outfile ) throw()
   {
 //  std::fprintf( outfile, "page size %dw x %dh\n", width(), height() );
   std::fprintf( outfile, "total zones in page %d\n", (int)zone_vector.size() );
@@ -72,24 +71,15 @@ void bprint( const std::vector< Zone > & zone_vector, FILE * outfile ) throw()
   for( unsigned int zindex = 0; zindex < zone_vector.size(); ++zindex )
     {
     const Rectangle & r = zone_vector[zindex].mask;
-//    const std::vector< std::vector< Blob * > > & blobp_matrix = zone_vector[zindex].blobp_matrix;
     const std::vector< Blob * > & blobp_vector = zone_vector[zindex].blobp_vector;
 
     std::fprintf( outfile, "zone %d of %d\n", zindex + 1, (int)zone_vector.size() );
     std::fprintf( outfile, "zone size %dw x %dh\n", r.width(), r.height() );
-//    std::fprintf( outfile, "total cuts in zone %d\n", (int)blobp_matrix.size() );
-//    std::fprintf( outfile, "total blobs in zone %d\n\n", blobs_in_zone( zone_vector, zindex ) );
     std::fprintf( outfile, "total blobs in zone %d\n\n",
                   (int)zone_vector[zindex].blobp_vector.size() );
 
-//    for( unsigned int cut = 0; cut < blobp_matrix.size(); ++cut )
-//      {
-//      std::fprintf( outfile, "cut %d blobs %d\n", cut + 1, (int)blobp_matrix[cut].size() );
-//      for( unsigned int i = 0; i < blobp_matrix[cut].size(); ++i )
-//        blobp_matrix[cut][i]->print( outfile );
-      for( unsigned int i = 0; i < blobp_vector.size(); ++i )
-        blobp_vector[i]->print( outfile );
-//      }
+    for( unsigned int i = 0; i < blobp_vector.size(); ++i )
+      blobp_vector[i]->print( outfile );
     }
   }
 
@@ -97,12 +87,12 @@ void bprint( const std::vector< Zone > & zone_vector, FILE * outfile ) throw()
 inline void join_blobs( std::vector< Blob * > & blobp_vector,
                          std::vector< Blob * > & v1,
                          std::vector< Blob * > & v2,
-                         Blob * p1, Blob * p2, int i ) throw()
+                         Blob * p1, Blob * p2, int i )
   {
   if( p1->top() > p2->top() )
     {
-    Blob * temp = p1; p1 = p2; p2 = temp;
-    std::replace( v2.begin(), v2.begin() + i + 1, p2, p1 );
+    Blob * const temp = p1; p1 = p2; p2 = temp;
+    std::replace( v2.begin(), v2.begin() + ( i + 1 ), p2, p1 );
     }
   else std::replace( v1.begin() + i, v1.end(), p2, p1 );
 
@@ -122,8 +112,10 @@ void ignore_abnormal_blobs( std::vector< Blob * > & blobp_vector ) throw()
     {
     Blob & b = *blobp_vector[i];
     if( b.height() > 35 * b.width() || b.width() > 25 * b.height() )
-      { delete blobp_vector[i];
-      blobp_vector.erase( blobp_vector.begin() + i ); }
+      {
+      delete blobp_vector[i];
+      blobp_vector.erase( blobp_vector.begin() + i );
+      }
     }
   }
 
@@ -133,7 +125,7 @@ void ignore_small_blobs( std::vector< Blob * > & blobp_vector ) throw()
   int to = 0, blobs = blobp_vector.size();
   for( int from = 0; from < blobs; ++from )
     {
-    Blob * p = blobp_vector[from];
+    Blob * const p = blobp_vector[from];
     if( p->height() > 4 || p->width() > 4 ||
         ( ( p->height() > 2 || p->width() > 2 ) && p->area() > 5 ) )
       { blobp_vector[from] = blobp_vector[to]; blobp_vector[to] = p; ++to; }
@@ -146,7 +138,7 @@ void ignore_small_blobs( std::vector< Blob * > & blobp_vector ) throw()
   }
 
 
-void remove_top_bottom_noise( std::vector< Blob * > & blobp_vector ) throw()
+void remove_top_bottom_noise( std::vector< Blob * > & blobp_vector )
   {
   int blobs = blobp_vector.size();
   for( int i = 0; i < blobs; ++i )
@@ -167,7 +159,7 @@ void remove_top_bottom_noise( std::vector< Blob * > & blobp_vector ) throw()
   }
 
 
-void remove_left_right_noise( std::vector< Blob * > & blobp_vector ) throw()
+void remove_left_right_noise( std::vector< Blob * > & blobp_vector )
   {
   int blobs = blobp_vector.size();
   for( int i = 0; i < blobs; ++i )
@@ -188,18 +180,13 @@ void remove_left_right_noise( std::vector< Blob * > & blobp_vector ) throw()
   }
 
 
-void find_holes( std::vector< Zone > & zone_vector ) throw()
+void find_holes( std::vector< Zone > & zone_vector )
   {
   for( unsigned int zi = 0; zi < zone_vector.size(); ++zi )
     {
-//    std::vector< std::vector< Blob * > > & blobp_matrix = zone_vector[zi].blobp_matrix;
     std::vector< Blob * > & blobp_vector = zone_vector[zi].blobp_vector;
-//    for( unsigned int bmi = 0; bmi < blobp_matrix.size(); ++bmi )
-//      {
-//      std::vector< Blob * > & blobp_vector = blobp_matrix[bmi];
-      for( unsigned int bvi = 0; bvi < blobp_vector.size(); ++bvi )
-        blobp_vector[bvi]->find_holes();
-//      }
+    for( unsigned int bvi = 0; bvi < blobp_vector.size(); ++bvi )
+      blobp_vector[bvi]->find_holes();
     }
   }
 
@@ -214,13 +201,16 @@ void ignore_wide_blobs( const Rectangle & re,
     blobp_vector.erase( blobp_vector.begin() + i );
     if( 4 * b.area() <= 3 * b.size() )
       {
-      unsigned int blobs;
-      for( blobs = i; blobs < blobp_vector.size(); ++blobs )
-        if( blobp_vector[blobs]->top() > b.bottom() ) break;
-      blobs -= i;
-      if( blobs <= b.size() / 400U )
+      int blobs = 0;
+      for( unsigned int j = i; j < blobp_vector.size(); ++j )
         {
-        if( 4 * b.area() <= b.size() ) { delete &b; continue; }
+        if( blobp_vector[j]->top() > b.bottom() ) break;
+        if( blobp_vector[j]->size() >= 16 ) ++blobs;
+        }
+      if( blobs <= b.size() / 400 )
+        {
+        if( 4 * b.area() <= b.size() )		// thin grid or frame
+          { delete &b; continue; }
         b.find_holes();
         bool frame = false;
         if( b.holes() < std::min( b.height(), b.width() ) )
@@ -233,26 +223,25 @@ void ignore_wide_blobs( const Rectangle & re,
         if( frame ) { delete &b; continue; }
         }
       }
-    // image, not frame
+    // picture, not frame
     if( 5 * b.width() > 4 * re.width() && 5 * b.height() > 4 * re.height() )
       {
       for( unsigned int j = 0; j < blobp_vector.size(); ++j )
         delete blobp_vector[j];
       blobp_vector.clear(); delete &b; break;
       }
-    for( int j = blobp_vector.size(); --j >= 0; )
+    for( unsigned int j = blobp_vector.size(); j > i; )
       {
-      const Blob & b2 = *blobp_vector[j];
+      const Blob & b2 = *blobp_vector[--j];
       if( b.includes( b2 ) )
         { delete &b2; blobp_vector.erase( blobp_vector.begin() + j ); }
-      else if( b2.top() < b.top() ) break;
       }
     delete &b;
     }
   }
 
 
-int mean_blob_height( const std::vector< Blob * > & blobp_vector ) throw()
+int mean_blob_height( const std::vector< Blob * > & blobp_vector )
   {
   int mean_height = 0;
   unsigned int samples = 0;
@@ -287,8 +276,8 @@ int mean_blob_height( const std::vector< Blob * > & blobp_vector ) throw()
   }
 
 
-int analyse_layout( const std::vector< Blob * > & blobp_vector,
-                    std::vector< Zone > & zone_vector ) throw()
+int analyse_layout( std::vector< Blob * > & blobp_vector,
+                    std::vector< Zone > & zone_vector )
   {
   if( !blobp_vector.size() ) return 0;
   const int mean_height = mean_blob_height( blobp_vector );
@@ -297,7 +286,7 @@ int analyse_layout( const std::vector< Blob * > & blobp_vector,
   for( unsigned int i = 1; i < blobp_vector.size(); ++i )
     {
     Blob & b = *blobp_vector[i];
-    if( b.height() > 10 * mean_height ) continue;
+    if( b.height() > 10 * mean_height ) { delete &b; continue; }
     int first = -1;
     for( unsigned int j = 0; j < zone_vector.size(); ++j )
       {
@@ -322,6 +311,7 @@ int analyse_layout( const std::vector< Blob * > & blobp_vector,
       zone_vector.back().blobp_vector.push_back( &b );
       }
     }
+  blobp_vector.clear();
 
   // sort zone_vector
   int botmax = ( zone_vector.size() ? zone_vector[0].mask.bottom() : 0 );
@@ -356,7 +346,7 @@ int analyse_layout( const std::vector< Blob * > & blobp_vector,
       {
       for( unsigned int i = begin + 1; i < end; ++i )
         zone_vector[begin].join( zone_vector[i] );
-      zone_vector.erase( zone_vector.begin() + begin + 1,
+      zone_vector.erase( zone_vector.begin() + ( begin + 1 ),
                          zone_vector.begin() + end );
       for( unsigned int i = cut; i < cut_index_vector.size(); ++i )
         cut_index_vector[i] -= ( end - begin - 1 );
@@ -369,7 +359,7 @@ int analyse_layout( const std::vector< Blob * > & blobp_vector,
 
 
 void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector,
-                const int debug_level, const bool layout ) throw()
+                const int debug_level, const bool layout )
   {
   const Rectangle & re = page_image;
   const int zthreshold = page_image.threshold();
@@ -377,10 +367,10 @@ void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector
   std::vector< Blob * > old_data( re.width(), (Blob *) 0 );
   std::vector< Blob * > new_data( re.width(), (Blob *) 0 );
 
-  for( int row = re.top() + 1; row <= re.bottom(); ++row )
+  for( int row = re.top(); row <= re.bottom(); ++row )
     {
     old_data.swap( new_data );
-    for( int col = re.left() + 1; col < re.right(); ++col )
+    for( int col = re.left(); col <= re.right(); ++col )
       {
       const int dcol = col - re.left();
       if( !page_image.get_bit( row, col, zthreshold ) )
@@ -388,10 +378,10 @@ void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector
       else					// black point
         {
         Blob *p;
-        Blob *lp  = new_data[dcol-1];
-        Blob *ltp = old_data[dcol-1];
+        Blob *lp  = ( (dcol > 0) ? new_data[dcol-1] : 0 );
+        Blob *ltp = ( (dcol > 0) ? old_data[dcol-1] : 0 );
         Blob *tp  = old_data[dcol];
-        Blob *rtp = old_data[dcol+1];
+        Blob *rtp = ( (col < re.right()) ? old_data[dcol+1] : 0 );
         if( lp )       { p = lp;  p->add_point( row, col ); }
         else if( ltp ) { p = ltp; p->add_point( row, col ); }
         else if( tp )  { p = tp;  p->add_point( row, col ); }
@@ -409,17 +399,17 @@ void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector
       }
     }
 
-  if( debug_level <= 99 )
+  if( debug_level <= 99 && blobp_vector.size() > 3 )
     {
-    if( (int)blobp_vector.size() > 3 )
-      ignore_wide_blobs( re, blobp_vector );
+    ignore_wide_blobs( re, blobp_vector );
     ignore_small_blobs( blobp_vector );
     ignore_abnormal_blobs( blobp_vector );
     remove_top_bottom_noise( blobp_vector );
     remove_left_right_noise( blobp_vector );
     }
 
-  if( layout && re.width() > 200 && re.height() > 200 )
+  if( layout && re.width() > 200 && re.height() > 200 &&
+      blobp_vector.size() > 3 )
     {
     analyse_layout( blobp_vector, zone_vector );
     if( debug_level <= 99 && zone_vector.size() > 1 )
@@ -437,8 +427,8 @@ void scan_page( const Page_image & page_image, std::vector< Zone > & zone_vector
 } // end namespace
 
 
-Textpage::Textpage( const Page_image & page_image, const char * filename,
-                    const Control & control, const bool layout ) throw()
+Textpage::Textpage( const Page_image & page_image, const char * const filename,
+                    const Control & control, const bool layout )
   : Rectangle( page_image ), name( filename )
   {
   const int debug_level = control.debug_level;
@@ -459,19 +449,14 @@ Textpage::Textpage( const Page_image & page_image, const char * filename,
   // build a Textblock for every zone with text
   for( unsigned int i = 0; i < zone_vector.size(); ++i )
     {
-    Textblock * tbp = new Textblock( page_image, zone_vector[i].mask,
-                                     zone_vector[i].blobp_vector );
-    if( debug_level < 90 )
+    Textblock * const tbp = new Textblock( page_image, zone_vector[i].mask,
+                                           zone_vector[i].blobp_vector );
+    if( tbp->textlines() && debug_level < 90 )
       tbp->recognize( control.charset, control.filter );
     if( tbp->textlines() ) tbpv.push_back( tbp );
     else delete tbp;
     }
-  if( debug_level == 0 )
-    {
-    if( control.outfile ) print( control );
-    if( control.exportfile ) xprint( control );
-    return;
-    }
+  if( debug_level == 0 ) return;
   if( !control.outfile ) return;
   if( debug_level >= 86 )
     {
@@ -510,14 +495,32 @@ Textpage::~Textpage() throw()
   for( int i = textblocks() - 1; i >= 0; --i ) delete tbpv[i];
   }
 
-/*
-const Textblock & Textpage::textblock( int i ) const throw()
+
+const Textblock & Textpage::textblock( const int i ) const throw()
   {
   if( i < 0 || i >= textblocks() )
     Ocrad::internal_error( "Textpage::textblock, index out of bounds" );
   return *(tbpv[i]);
   }
-*/
+
+
+int Textpage::textlines() const throw()
+  {
+  int total = 0;
+  for( int i = 0; i < textblocks(); ++i )
+    total += tbpv[i]->textlines();
+  return total;
+  }
+
+
+int Textpage::characters() const throw()
+  {
+  int total = 0;
+  for( int i = 0; i < textblocks(); ++i )
+    total += tbpv[i]->characters();
+  return total;
+  }
+
 
 void Textpage::print( const Control & control ) const throw()
   {
