@@ -1,5 +1,5 @@
 /*  GNU Ocrad - Optical Character Recognition program
-    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+    Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011
     Antonio Diaz Diaz.
 
     This program is free software: you can redistribute it and/or modify
@@ -241,7 +241,8 @@ bool UCS::isvowel( int code ) throw()
   if( code >= 128 ) code = base_letter( code );
   if( !code || !std::isalpha( code ) ) return false;
   code = std::tolower( code );
-  return ( code == 'a' || code == 'e' || code == 'i' || code == 'o' || code == 'u' );
+  return ( code == 'a' || code == 'e' || code == 'i' ||
+           code == 'o' || code == 'u' );
   }
 
 
